@@ -1,17 +1,27 @@
 library(restatapi)
 library(tinytest)
 
+api_version="new"
+source="local"
+load_cfg(api_version,source)
+
 if (parallel::detectCores()<=2){
   options(restatapi_cores=1)
 }else{
   options(restatapi_cores=2)
-}    
+}  
+
+if (Sys.info()[['sysname']]=='Windows'){
+  options(restatapi_cores=1)
+}
+
 if (capabilities("libcurl")){
   options(restatapi_dmethod="libcurl")
 }
 
 options(restatapi_verbose=TRUE)
 options(restatapi_log=FALSE)
+get("rav",envir=restatapi::.restatapi_env)
 clean_restatapi_cache()
 no_check<-NULL
 
@@ -28,54 +38,64 @@ testid11<-"nrg_pc_206_h"
 testid12<-"ei_bsfs_q"
 testid13<-"avia_par_mk"
 
+tm<-function(tn,msg){
+  message("\n m########--------- ",tn,msg)
+  # cat("\n c########--------- ",tn,msg)
+  # paste("\n p########--------- ",tn,msg)
 
+  return(tn+1)
+}
+
+tn<-1
 
 
 t1<-system.time({xml_toc<-get_eurostat_toc(verbose=TRUE)})[3]
 txt_toc<-get_eurostat_toc(mode="txt")
 t2<-system.time({get_eurostat_toc()})[3]
-message("\n ########--------- 1 test of the get_eurostat_toc function")
+tn<-tm(tn, " test of the get_eurostat_toc function")
 expect_error(get_eurostat_toc(mode="text"))
 if (!is.null(xml_toc)){
-  message("\n ########--------- 2 test of the get_eurostat_toc function")
+  tn<-tm(tn, " test of the get_eurostat_toc function")
   expect_equal(ncol(xml_toc),14)
-  message("\n ########--------- 3 test of the get_eurostat_toc function")
+  tn<-tm(tn, " test of the get_eurostat_toc function")
   expect_true(exists("toc.xml.en",envir=restatapi::.restatapi_env))
   if (!is.null(txt_toc)){
-    message("\n ########--------- 4 test of the get_eurostat_toc function")
+    tn<-tm(tn, " test of the get_eurostat_toc function")
     expect_equal(ncol(txt_toc),8)
-    message("\n ########--------- 5 test of the get_eurostat_toc function")
+    tn<-tm(tn, " test of the get_eurostat_toc function")
     expect_equal(nrow(xml_toc),nrow(txt_toc))
-    message("\n ########--------- 6 test of the get_eurostat_toc function")
+    tn<-tm(tn, " test of the get_eurostat_toc function")
     expect_true(exists("toc.txt.en",envir=restatapi::.restatapi_env))
-    message("\n ########--------- 7 test of the get_eurostat_toc function")
+    tn<-tm(tn, " test of the get_eurostat_toc function")
     expect_true(t2<t1)
-  } else {no_check<-paste(no_check,"4-7",sep=", ")} 
-} else {no_check<-paste(no_check,"2-7",sep=", ")}
+  } else {no_check<-paste(no_check,tn,"-",tn+3,sep=", ");tn<-tn+3} 
+} else {no_check<-paste(no_check,tn,"-",tn+5,sep=", ");tn<-tn+5}
 
 r1<-search_eurostat_toc("energy")
 r2<-search_eurostat_toc("energy",ignore.case=TRUE)
 r3<-search_eurostat_toc("energie",lang="de",ignore.case=TRUE)
 if (!is.null(r1)&!is.null(r2)){
-  message("\n ########--------- 8 test of the search_eurostat_toc function")
+  tn<-tm(tn, " test of the search_eurostat_toc function")
   expect_true(nrow(r1)<nrow(r2))
-} else {no_check<-paste(no_check,"8",sep=", ")}
+} else {no_check<-paste(no_check,tn,sep=", ");tn<-tn+1}
 if (!is.null(r3)){
-  message("\n ########--------- 9 test of the search_eurostat_toc function")
+  tn<-tm(tn, " test of the search_eurostat_toc function")
   expect_true(nrow(r3)>80)
-} else {no_check<-paste(no_check,"9",sep=", ")}
+} else {no_check<-paste(no_check,tn,sep=", ");tn<-tn+1}
 
-message("\n ########--------- 10 test of the get_eurostat_dsd function")
+tn<-tm(tn, " test of the get_eurostat_dsd function")
 expect_equal(get_eurostat_dsd("text"),NULL)
 
 dsd<-get_eurostat_dsd(testid1)
 if (!is.null(dsd)){
-  message("\n ########--------- 11 test of the get_eurostat_dsd function")
+  tn<-tm(tn, " test of the get_eurostat_dsd function")
+  expect_true(data.table::is.data.table(dsd))
+  tn<-tm(tn, "  test of the get_eurostat_dsd function")
   expect_equal(ncol(dsd),3)
-  message("\n ########--------- 12 test of the get_eurostat_dsd function")
+  tn<-tm(tn, "  test of the get_eurostat_dsd function")
   expect_true(exists(paste0(testid1,".dsd"),envir=restatapi::.restatapi_env))
-} else {no_check<-paste(no_check,"11-12",sep=", ")} 
-if (!is.null(xml_toc)){}
+} else {no_check<-paste(no_check,tn,"-",tn+2,sep=", ");tn<-tn+2} 
+# if (!is.null(xml_toc)){}
 
 eu<-get("cc",envir=restatapi::.restatapi_env)
 pattern<-"EU"
@@ -88,7 +108,7 @@ if (!is.null(xml_toc)){
     message("\n ########--------- 15 test of the search_eurostat_dsd function")
     expect_equal(ncol(search_eurostat_dsd(pattern,dsd)),4)
     message("\n ########--------- 16 test of the search_eurostat_dsd function")
-    expect_equal(nrow(search_eurostat_dsd(pattern,dsd,ignore.case=TRUE)),20)
+    expect_equal(nrow(search_eurostat_dsd(pattern,dsd,ignore.case=TRUE)),19)
     message("\n ########--------- 17 test of the search_eurostat_dsd function")
     expect_equal(nrow(search_eurostat_dsd(pattern,dsd)),15)
     message("\n ########--------- 18 test of the search_eurostat_dsd function")
@@ -120,22 +140,25 @@ if (!is.null(dt1)&is.data.frame(dt1)&!is.null(dt2)&is.data.frame(dt2)){
 
 if (!is.null(xml_toc)){
   testid3<-xml_toc$code[is.na(xml_toc$values)&is.na(xml_toc$lastUpdate)&is.na(xml_toc$downloadLink.tsv)][1]
-  message("\n ########--------- 25 test of the get_eurostat_raw/bulk/data functions")
-  expect_message(rt1<-get_eurostat_raw(testid3,verbose=FALSE))
-  message("\n ########--------- 26 test of the get_eurostat_raw/bulk/data functions")
-  expect_equal(rt1,NULL)
-  message("\n ########--------- 27 test of the get_eurostat_raw/bulk/data functions")
-  expect_message(rt2<-get_eurostat_raw(testid3,check_toc=TRUE,verbose=FALSE))
-  message("\n ########--------- 28 test of the get_eurostat_raw/bulk/data functions")
-  expect_equal(rt2,NULL)
-  message("\n ########--------- 29 test of the get_eurostat_raw/bulk/data functions")
-  expect_message(bt1<-get_eurostat_bulk("blabla",check_toc=TRUE,verbose=FALSE))
-  message("\n ########--------- 30 test of the get_eurostat_raw/bulk/data functions")
-  expect_equal(bt1,NULL)
-  message("\n ########--------- 31 test of the get_eurostat_raw/bulk/data functions")
-  expect_message(dt3<-get_eurostat_data(testid3,verbose=FALSE))
-  message("\n ########--------- 32 test of the get_eurostat_raw/bulk/data functions")
-  expect_equal(dt3,NULL)
+  # testid3<-xml_toc$code[(xml_toc$shortDescription=="")&is.na(xml_toc$metadata.html)&is.na(xml_toc$metadata.sdmx)][1]
+  if (!is.na(testid3)){
+    message("\n ########--------- 25 test of the get_eurostat_raw/bulk/data functions")
+    expect_message(rt1<-get_eurostat_raw(testid3,verbose=FALSE))
+    message("\n ########--------- 26 test of the get_eurostat_raw/bulk/data functions")
+    expect_equal(rt1,NULL)
+    message("\n ########--------- 27 test of the get_eurostat_raw/bulk/data functions")
+    expect_message(rt2<-get_eurostat_raw(testid3,check_toc=TRUE,verbose=FALSE))
+    message("\n ########--------- 28 test of the get_eurostat_raw/bulk/data functions")
+    expect_equal(rt2,NULL)
+    message("\n ########--------- 29 test of the get_eurostat_raw/bulk/data functions")
+    expect_message(bt1<-get_eurostat_bulk("blabla",check_toc=TRUE,verbose=FALSE))
+    message("\n ########--------- 30 test of the get_eurostat_raw/bulk/data functions")
+    expect_equal(bt1,NULL)
+    message("\n ########--------- 31 test of the get_eurostat_raw/bulk/data functions")
+    expect_message(dt3<-get_eurostat_data(testid3,verbose=FALSE))
+    message("\n ########--------- 32 test of the get_eurostat_raw/bulk/data functions")
+    expect_equal(dt3,NULL)  
+  }
 } else {no_check<-paste(no_check,"25-32",sep=", ")}
 rt3<-get_eurostat_raw(testid4,mode="xml",stringsAsFactors=TRUE,keep_flags=TRUE)
 bt2<-get_eurostat_data(testid4,keep_flags=TRUE,stringsAsFactors=FALSE)
@@ -188,9 +211,11 @@ message("\n ########--------- 45 test of filtering in the get_eurostat_data func
 expect_true(is.null(dt8))
 dt9<-get_eurostat_data(testid4,filters="2018",cflags=TRUE)
 if (!is.null(dt9)&is.data.frame(dt9)&!is.null(xml_toc)){
-  if (!is.na(as.numeric(xml_toc$values[xml_toc$code==testid4]))){
-    message("\n ########--------- 46 test of filtering in the get_eurostat_data function")
-    expect_equal(nrow(dt9),as.numeric(xml_toc$values[xml_toc$code==testid4]))
+  if (testid4 %in% xml_toc$code) {
+    if (!is.na(as.numeric(xml_toc$values[xml_toc$code==testid4]))){
+      message("\n ########--------- 46 test of filtering in the get_eurostat_data function")
+      expect_equal(nrow(dt9),as.numeric(xml_toc$values[xml_toc$code==testid4]))
+    } else {no_check<-paste(no_check,"46",sep=", ")}  
   } else {no_check<-paste(no_check,"46",sep=", ")}
 } else {no_check<-paste(no_check,"46",sep=", ")} 
 dsd1<-get_eurostat_dsd(testid4)
@@ -203,7 +228,7 @@ if (!is.null(dsd1)&is.data.frame(dsd1)){
     message("\n ########--------- 48 test of filtering in the get_eurostat_data function")
     expect_true(nrow(dt10)<nrow(dt11))
   } else {no_check<-paste(no_check,"47-48",sep=", ")}
-  nr1<-nrow(get_eurostat_data(testid4,date_filter=2016))
+  nr1<-nrow(get_eurostat_data(testid4,date_filter=2016,mode="xml"))
   nr2<-nrow(get_eurostat_data(testid4,date_filter="2016",keep_flags=TRUE))
   if (!is.null(nr1)&!is.null(nr2)){
     message("\n ########--------- 49 test of filtering in the get_eurostat_data function")
@@ -217,18 +242,18 @@ if (!is.null(dsd1)&is.data.frame(dsd1)){
   nr4<-nrow(get_eurostat_data(testid4,filters="BE$",date_filter="2006-02:2008-06-05",label=TRUE))
   if (!is.null(nr4)){
     message("\n ########--------- 51 test of filtering in the get_eurostat_data function")
-    expect_equal(nr4,2)
+    expect_equal(nr4,1)
   } else {no_check<-paste(no_check,"51",sep=", ")}
   nr5<-nrow(get_eurostat_data(testid4,filters="BE",date_filter="<2008",cflags=TRUE))
   if (!is.null(nr5)){
     message("\n ########--------- 52 test of filtering in the get_eurostat_data function")
     expect_equal(nr5,11)
   } else {no_check<-paste(no_check,"52",sep=", ")} 
-  nr6<-nrow(get_eurostat_data(testid6,filters="Q...ME_LYPG_HU_LHBP+ME_LYTV_UA_UKKK",date_filter=c("2017-07-01"),select_freq="M",cflags=TRUE))
+  nr6<-nrow(get_eurostat_data(testid6,filters="Q...ME_LYPG_HU_LHBP+ME_LYTV_UA_UKKK",date_filter=c("2017-07-01:2017-09-30"),select_freq="M",cflags=TRUE))
   if (!is.null(nr6)){
     message("\n ########--------- 53 test of filtering in the get_eurostat_data function")
-    expect_equal(nr6,48)
-  } else {no_check<-paste(no_check,"53",sep=", ")} 
+    expect_equal(nr6,96)
+  } else {no_check<-paste(no_check,"53",sep=", ")}
 } else {no_check<-paste(no_check,"47-53",sep=", ")} 
 
 dsd2<-get_eurostat_dsd(testid6)
@@ -332,7 +357,7 @@ if (!is.null(dsd)){
   message("\n ########--------- 85 test of the create_filter_table function")
   expect_equal(ncol(ft1),ncol(ft2))
   message("\n ########--------- 86 test of the create_filter_table function")
-  expect_equal(nrow(ft1),10)
+  expect_equal(nrow(ft1),11)
   message("\n ########--------- 87 test of the create_filter_table function")
   expect_equal(nrow(ft2),2)
 } else {no_check<-paste(no_check,"84-87",sep=", ")}
@@ -361,9 +386,14 @@ if (!is.null(rd)){
   expect_equal(nrow(frd),9316)
 } else {no_check<-paste(no_check,"91-93",sep=", ")}
 
+
+##################################
+# additional test not on CRAN    #
+##################################
+
 if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
   message("\n ########--------- 94 additional test of the get_eurostat_dsd function") 
-  expect_true(system.time({get_eurostat_dsd(testid1)})[3]<system.time({get_eurostat_dsd(testid1,update_cache=TRUE,parallel=FALSE)})[3])
+  expect_true(system.time({get_eurostat_dsd(testid1)})[3]<system.time({get_eurostat_dsd(testid1,update_cache=TRUE,parallel=FALSE,api_version=api_version)})[3])
   
   dsd1<-get_eurostat_dsd(testid4)
   if (!is.null(dsd1)&is.data.frame(dsd1)){
@@ -386,7 +416,7 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
       message("\n ########--------- 97 additional tests for filtering in the get_eurostat_data function")
       expect_equal(nr9,24)
     } else {no_check<-paste(no_check,"97",sep=", ")}
-    nr10<-nrow(get_eurostat_data(testid6,date_filter=c(2016,"2017-03","2017-05","2017-07-01"),select_freq="Q",cflags=TRUE))
+    nr10<-nrow(get_eurostat_data(testid6,date_filter=c(2016,"2017-03","2017-05","2017-07-01:2017-09-30"),select_freq="Q",cflags=TRUE))
     if (!is.null(nr10)){
       message("\n ########--------- 98 additional tests for filtering in the get_eurostat_data function")
       expect_equal(nr10,1232)
@@ -408,7 +438,7 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
       message("\n ########--------- 102 additional tests for filtering in the get_eurostat_data function")
       expect_false(any(sapply(dt6,is.factor)))
     } else {no_check<-paste(no_check,"102",sep=", ")}
-    dt8<-get_eurostat_data(testid6,filters="BE$",date_filter=c("2017-03",2016,"2017-07-01",2012:2014),select_freq="Q",label=TRUE,verbose=FALSE,name=FALSE)
+    dt8<-get_eurostat_data(testid6,filters="BE$",date_filter=c("2017-03",2016,"2017-07-01:2017-09-30",2012:2014),select_freq="Q",label=TRUE,verbose=FALSE,name=FALSE)
     if (!is.null(dt8)){
       message("\n ########--------- 103 additional tests for filtering in the get_eurostat_data function")
       expect_true(nrow(dt8)<=5040)
@@ -433,7 +463,7 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
     nr11<-nrow(get_eurostat_data(testid9,filters="Monthly",exact_match=FALSE,date_filter=c("<2018-07-01"),select_freq="A",label=TRUE,name=FALSE))
     if (!is.null(nr11)){
       message("\n ########--------- 107 additional tests for filtering in the get_eurostat_data function")
-      expect_equal(nr11,5565)
+      expect_equal(nr11,4845)
     } else {no_check<-paste(no_check,"107",sep=", ")}
   } else {no_check<-paste(no_check,"107",sep=", ")}
   dsd4<-get_eurostat_dsd(testid10)
@@ -482,33 +512,39 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
   raw2<-get_eurostat_raw(testid4,mode="xml",keep_flags=TRUE,stringsAsFactors=FALSE,update_cache=TRUE)
   bulk2<-get_eurostat_bulk(testid4,keep_flags=TRUE)
   if (!is.null(bulk1)&!is.null(bulk2)){
-    kc<-colnames(bulk1)[1:(ncol(bulk1)-1)]
-    data.table::setorderv(bulk1,kc)
-    data.table::setorderv(bulk2,kc)
+    kc<-colnames(bulk1)
+    bulk1<-bulk1[,..kc]
+    bulk1<-bulk2[,..kc]
+    data.table::setorder(bulk1)
+    data.table::setorder(bulk2)
     message("\n ########--------- 119 additional tests for the get_eurostat_raw/bulk function")
     expect_true(identical(bulk1,bulk2))
   } else {no_check<-paste(no_check,"119",sep=", ")}
-  clean_restatapi_cache()
-  raw1<-get_eurostat_raw(testid4,keep_flags=TRUE,update_cache=TRUE)
-  bulk1<-get_eurostat_bulk(testid4,check_toc=TRUE)
-  raw2<-get_eurostat_raw(testid4,mode="xml",keep_flags=TRUE,stringsAsFactors=FALSE,update_cache=TRUE)
-  bulk2<-get_eurostat_bulk(testid4)
-  if (!is.null(bulk1)&!is.null(bulk2)){
-    kc<-colnames(bulk1)[1:(ncol(bulk1)-1)]
-    data.table::setorderv(bulk1,kc)
-    data.table::setorderv(bulk2,kc)
-    message("\n ########--------- 120 additional tests for the get_eurostat_raw/bulk function")
-    expect_true(identical(bulk1,bulk2))
-  } else {no_check<-paste(no_check,"120",sep=", ")}
+  # clean_restatapi_cache()
+  # raw1<-get_eurostat_raw(testid4,keep_flags=TRUE,update_cache=TRUE)
+  # bulk1<-get_eurostat_bulk(testid4,check_toc=TRUE)
+  # raw2<-get_eurostat_raw(testid4,mode="xml",keep_flags=TRUE,stringsAsFactors=FALSE,update_cache=TRUE)
+  # bulk2<-get_eurostat_bulk(testid4)
+  # if (!is.null(bulk1)&!is.null(bulk2)){
+  #   kc<-colnames(bulk1)
+  #   bulk1<-bulk1[,..kc]
+  #   bulk1<-bulk2[,..kc]
+  #   data.table::setorder(bulk1)
+  #   data.table::setorder(bulk2)
+  #   message("\n ########--------- 120 additional tests for the get_eurostat_raw/bulk function")
+  #   expect_true(identical(bulk1,bulk2))
+  # } else {no_check<-paste(no_check,"120",sep=", ")}
   clean_restatapi_cache()
   raw1<-get_eurostat_raw(testid4,keep_flags=TRUE,update_cache=TRUE)
   bulk1<-get_eurostat_bulk(testid4,check_toc=TRUE,stringsAsFactors=FALSE)
   raw2<-get_eurostat_raw(testid4,mode="xml",stringsAsFactors=FALSE,update_cache=TRUE)
   bulk2<-get_eurostat_bulk(testid4,stringsAsFactors=FALSE)
   if (!is.null(bulk1)&!is.null(bulk2)){
-    kc<-colnames(bulk1)[1:(ncol(bulk1)-1)]
-    data.table::setorderv(bulk1,kc)
-    data.table::setorderv(bulk2,kc)
+    kc<-colnames(bulk1)
+    bulk1<-bulk1[,..kc]
+    bulk1<-bulk2[,..kc]
+    data.table::setorder(bulk1)
+    data.table::setorder(bulk2)
     message("\n ########--------- 121 additional tests for the get_eurostat_raw/bulk function")
     expect_true(identical(bulk1,bulk2))
   } else {no_check<-paste(no_check,"121",sep=", ")}
@@ -518,9 +554,11 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
   raw2<-get_eurostat_raw(testid4,mode="xml",check_toc=TRUE,update_cache=TRUE)
   bulk2<-get_eurostat_bulk(testid4,check_toc=TRUE,keep_flags=TRUE)
   if (!is.null(bulk1)&!is.null(bulk2)){
-    kc<-colnames(bulk1)[1:(ncol(bulk1)-1)]
-    data.table::setorderv(bulk1,kc)
-    data.table::setorderv(bulk2,kc)
+    kc<-colnames(bulk1)
+    bulk1<-bulk1[,..kc]
+    bulk1<-bulk2[,..kc]
+    data.table::setorder(bulk1)
+    data.table::setorder(bulk2)
     message("\n ########--------- 122 additional tests for the get_eurostat_raw/bulk function")
     expect_true(identical(bulk1,bulk2))
   } else {no_check<-paste(no_check,"122",sep=", ")}
@@ -530,9 +568,11 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
   raw2<-get_eurostat_raw(testid11,mode="xml",check_toc=TRUE,keep_flags=TRUE,update_cache=TRUE)
   bulk2<-get_eurostat_bulk(testid11)
   if (!is.null(bulk1)&!is.null(bulk2)){
-    kc<-colnames(bulk1)[1:(ncol(bulk1)-1)]
-    data.table::setorderv(bulk1,kc)
-    data.table::setorderv(bulk2,kc)
+    kc<-colnames(bulk1)
+    bulk1<-bulk1[,..kc]
+    bulk1<-bulk2[,..kc]
+    data.table::setorder(bulk1)
+    data.table::setorder(bulk2)
     message("\n ########--------- 123 additional tests for the get_eurostat_raw/bulk function")
     expect_true(identical(bulk1,bulk2))
   } else {no_check<-paste(no_check,"123",sep=", ")}
@@ -542,9 +582,11 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
   raw2<-get_eurostat_raw(testid11,mode="xml",keep_flags=TRUE,stringsAsFactors=FALSE,check_toc=TRUE,update_cache=TRUE)
   bulk2<-get_eurostat_bulk(testid11,keep_flags=TRUE,stringsAsFactors=FALSE)
   if (!is.null(bulk1)&!is.null(bulk2)){
-    kc<-colnames(bulk1)[1:(ncol(bulk1)-1)]
-    data.table::setorderv(bulk1,kc)
-    data.table::setorderv(bulk2,kc)
+    kc<-colnames(bulk1)
+    bulk1<-bulk1[,..kc]
+    bulk1<-bulk2[,..kc]
+    data.table::setorder(bulk1)
+    data.table::setorder(bulk2)
     message("\n ########--------- 124 additional tests for the get_eurostat_raw/bulk function")
     expect_true(identical(bulk1,bulk2))
   } else {no_check<-paste(no_check,"124",sep=", ")}
@@ -571,7 +613,7 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
   rt3<-system.time(raw3<-get_eurostat_raw(testid12,"xml",verbose=TRUE))[3]
   dt1<-system.time(estat_data1<-get_eurostat_data(testid12,keep_flags=TRUE,verbose=TRUE))[3]
   dt2<-system.time(estat_data2<-get_eurostat_data(testid12,stringsAsFactors=FALSE,verbose=TRUE))[3]
-  dt3<-system.time(estat_data3<-get_eurostat_data(testid12,keep_flags=TRUE,verbose=TRUE))[3]
+  dt3<-system.time(estat_data3<-get_eurostat_data(testid12,keep_flags=TRUE,verbose=FALSE))[3]
   testid13<-"avia_par_mk"
   suppressWarnings(dt4<-system.time(estat_data4<-get_eurostat_data(testid13,stringsAsFactors=FALSE))[3])
   rt4<-system.time(raw4<-get_eurostat_raw(testid13,"xml",keep_flags=TRUE))[3]
@@ -655,6 +697,22 @@ if (grepl("\\.amzn|-aws|5.4.109+",Sys.info()['release'])) {
   } else {no_check<-paste(no_check,"158",sep=", ")}
   
 }
+
+
+##################################
+# new tests                      #
+##################################
+
+cl<-get_eurostat_codelist("freq",lang="de",cache=FALSE,verbose=TRUE)
+if (!is.null(cl)){
+  message("\n ########--------- 159 test of the get_eurostat_codelist function")
+  expect_equal(ncol(cl),2)
+  message("\n ########--------- 160 test of the get_eurostat_codelist function")
+  expect_equal(nrow(cl),10)
+}
+
+
+
 clean_restatapi_cache(tempdir(),verbose=TRUE)
 if (!is.null(no_check)) {message("\n\n\n\n\nThere are skipped tests:",gsub("^,","",no_check))}
-cat("\n\n\n\n\n\nSkipped tests:", no_check)
+cat("\n\nSkipped tests:",gsub("^,","",no_check),"\nconfig version:",get("rav",envir=restatapi::.restatapi_env),"\n")
